@@ -2,7 +2,7 @@ package Anonymous::Object;
 use strict;
 use warnings;
 use Data::Dumper;
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 our $UNIQUE;
 BEGIN {
@@ -318,12 +318,8 @@ sub add_method {
 sub build {
 	my ($self) = @_;
 
-	$self->add_method(
-		{
-			name => 'new',
-			code => $self->add_new( $self->default )
-		}
-	);
+
+	$self->meta->{new} = $self->add_new( $self->default );
 
 	my $class = sprintf q|%s::%s|, $self->{object_name}, $UNIQUE++;
 	my @methods;
@@ -386,7 +382,7 @@ Anonymous::Object - Generate Anonymous Objects
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
